==> qtjambi-sensors-6.3.0-sources.jar: io/qt/sensors/QAmbientTemperatureSensor.java <==
package io.qt.sensors;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qambienttemperaturesensor.html">QAmbientTemperatureSensor</a></p>
 */
public class QAmbientTemperatureSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAmbientTemperatureSensor.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QAmbientTemperatureSensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QAmbientTemperatureSensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qambienttemperaturesensor.html#QAmbientTemperatureSensor">QAmbientTemperatureSensor::QAmbientTemperatureSensor(QObject*)</a></p>
     */
    public QAmbientTemperatureSensor(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAmbientTemperatureSensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::reading()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.sensors.QAmbientTemperatureReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.sensors.QAmbientTemperatureReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAmbientTemperatureSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAmbientTemperatureSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAmbientTemperatureSensor instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-sensors-6.5.2-sources.jar: io/qt/sensors/QAmbientTemperatureSensor.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qambienttemperaturesensor.html">QAmbientTemperatureSensor</a></code></p>
 */
public class QAmbientTemperatureSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAmbientTemperatureSensor.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QAmbientTemperatureSensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QAmbientTemperatureSensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qambienttemperaturesensor.html#QAmbientTemperatureSensor">QAmbientTemperatureSensor::<wbr>QAmbientTemperatureSensor(QObject*)</a></code></p>
     */
    public QAmbientTemperatureSensor(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAmbientTemperatureSensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::<wbr>reading()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QAmbientTemperatureReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QAmbientTemperatureReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QAmbientTemperatureSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QAmbientTemperatureSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QAmbientTemperatureSensor instance, QDeclarativeConstructor constructor);
    
}
